@@ -1,3 +1,4 @@
+# coding: utf-8
 import mimetypes
 import os
 
@@ -22,7 +23,7 @@ from sorl.thumbnail import ImageField
 from sorl.thumbnail.helpers import ThumbnailError
 from sorl.thumbnail import get_thumbnail
 
-from tinymce.models import HTMLField
+from ckeditor.fields import RichTextField
 
 
 class Dated(models.Model):
@@ -79,7 +80,7 @@ class SiteEntityQuerySet(QuerySet):
 
 
 class Titled(models.Model):
-    """A properly formatted name used for human identification of an item."""
+    """This is the name that will be used to represent the item."""
     title = models.CharField(max_length=255,
         help_text=_(__doc__),
         verbose_name=_('title'))
@@ -92,8 +93,9 @@ class Titled(models.Model):
 
 
 class Statused(models.Model):
-    """Used to determine, for instance, whether this item appears on the site,
-    or is available to look at by the end-user."""
+    """Choosing ‘Live’ will make the item visible on the website. Choosing
+    'Draft' will store the item in the admin - you will be able to make it
+    live at a later date."""
 
     STATUS = Choices(
         ('draft', 'Draft'),
@@ -110,13 +112,10 @@ class Statused(models.Model):
 
 
 class Slugged(models.Model):
-    """The slug is the part of the URL distinct to this item (eg. if our item
-    was called Potato and the URL was /vegetables/ potato, the slug would
-    be "potato". Usually it is just a simplified, lower case version of the
-    item name. It is also automatically generated by default.
-
-    It is recommended to keep this the same even when changing an item's
-    name or title, for SEO purposes and to prevent broken inbound links.
+    """The slug is the last section of text at the end of the web address
+    shown in the address bar in your browser. The slug represents the
+    item and should not be changed to avoid breaking links coming in
+    from other websites.
     """
 
     slug = models.SlugField(max_length=255, db_index=True,
@@ -128,10 +127,8 @@ class Slugged(models.Model):
 
 
 class Bodied(models.Model):
-    """The body of a document is usually associated with the bulk of the
-    content associated with an item, for instance a description or the content
-    of a page."""
-    body = HTMLField(null=True, blank=True,
+    """This is the main content of the item."""
+    body = RichTextField(null=True, blank=True,
         help_text=_(__doc__),
         verbose_name=_('content'))
 
@@ -272,25 +269,23 @@ class Page(MPTTModel, Displayable, MetaInfo):
     parent = TreeForeignKey('self', null=True, blank=True,
         related_name='children',
         verbose_name=_('parent page'),
-        help_text=_("""The page that this one will be "below". There is only
-            one page which does not have a parent, which is the home page, and
-            all other pages must in some way inherit from this. This structure
-            is used to build URLs from page slugs."""))
+        help_text=_("""All pages must have a parent page. Main pages like
+            "services" have the parent "home". Sub pages like "painting"
+            or "decorating" would have the parent "services"."""))
 
     url = models.CharField(max_length=255, null=True, blank=True)
 
     header_title = models.CharField(max_length=255, blank=True,
         verbose_name=_('title'),
-        help_text=_("""Title for the page's header section (template support
-            required)"""))
+        help_text=_("""This is a title that will appear in the page's
+            header."""))
     header_image = ImageField(upload_to='page_headers', null=True, blank=True,
         verbose_name=_('image'),
-        help_text=_("""Image for the page's header section (template support
-            required)"""))
-    header_content = HTMLField(blank=True, null=True,
+        help_text=_("""This is the unique, main image used at the head of
+            the page."""))
+    header_content = RichTextField(blank=True, null=True,
         verbose_name=_('content'),
-        help_text=_("""Content for the page's header section (template support
-            required)"""))
+        help_text=_("""This content will appear in the page's header."""))
 
     objects = PassThroughManager.for_queryset_class(SiteEntityQuerySet)()
 
